@@ -39,7 +39,7 @@ test_that("mlflow can save model function", {
   temp_in_json_split <- tempfile(fileext = ".json")
   temp_out <- tempfile(fileext = ".json")
   write.csv(iris, temp_in_csv, row.names = FALSE)
-  mlflow_cli("models", "predict", "-m", testthat_model_name, "-i", temp_in_csv, "-o", temp_out, "-t", "csv", "--install-mlflow")
+  mlflow_cli("models", "predict", "-m", testthat_model_name, "-i", temp_in_csv, "-o", temp_out, "-t", "csv", "--env-manager", "uv", "--install-mlflow")
   prediction <- unlist(jsonlite::read_json(temp_out))
   expect_true(!is.null(prediction))
   expect_equal(
@@ -48,7 +48,7 @@ test_that("mlflow can save model function", {
   )
   # json records
   jsonlite::write_json(list(dataframe_records = iris), temp_in_json, row.names = FALSE)
-  mlflow_cli("models", "predict", "-m", testthat_model_name, "-i", temp_in_json, "-o", temp_out, "-t", "json", "--install-mlflow")
+  mlflow_cli("models", "predict", "-m", testthat_model_name, "-i", temp_in_json, "-o", temp_out, "-t", "json", "--env-manager", "uv", "--install-mlflow")
   prediction <- unlist(jsonlite::read_json(temp_out))
   expect_true(!is.null(prediction))
   expect_equal(
@@ -63,7 +63,7 @@ test_that("mlflow can save model function", {
       data = as.matrix(iris[, 1:4])))
   jsonlite::write_json(iris_split, temp_in_json_split, row.names = FALSE)
   mlflow_cli("models", "predict", "-m", testthat_model_name, "-i", temp_in_json_split, "-o", temp_out, "-t",
-             "json", "--install-mlflow")
+             "json", "--env-manager", "uv", "--install-mlflow")
   prediction <- unlist(jsonlite::read_json(temp_out))
   expect_true(!is.null(prediction))
   expect_equal(
@@ -93,11 +93,11 @@ test_that("mlflow can log model and load it back with a uri", {
   temp_out  <- tempfile(fileext = ".json")
   jsonlite::write_json(list(dataframe_records=0:10), temp_in)
   mlflow:::mlflow_cli("models", "predict", "-m", runs_uri, "-i", temp_in, "-o", temp_out,
-                      "--content-type", "json", "--install-mlflow")
+                      "--content-type", "json", "--env-manager", "uv", "--install-mlflow")
   prediction <- unlist(jsonlite::read_json(temp_out))
   expect_true(5 == prediction)
   mlflow:::mlflow_cli("models", "predict", "-m", actual_uri, "-i", temp_in, "-o", temp_out,
-                      "--content-type", "json", "--install-mlflow")
+                      "--content-type", "json", "--env-manager", "uv", "--install-mlflow")
   prediction <- unlist(jsonlite::read_json(temp_out))
   expect_true(5 == prediction)
 })
